read.cdffile.list: Read CDF file into an R list
Description
This function reads the entire contents of a cdf file into
an R list structureUsage
read.cdffile.list(filename, cdf.path = getwd())
Value
- returns a
list structure. The exact contents may vary
depending on the file format of the cdf file (see check.cdf.type)
Details
Note that this function can be very memory intensive with large CDF files.